@@ -1,6 +1,5 @@
 import secrets
-from re import L
-from typing import List, Optional
+from typing import List, Optional, Tuple, cast
 
 from pydantic import UUID4
 from sqlalchemy import Column, ForeignKey
@@ -28,6 +27,13 @@ class LoginSession(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     prompt: Optional[str] = Column(String(length=255), nullable=True)
     state: Optional[str] = Column(String(length=2048), nullable=True)
     nonce: Optional[str] = Column(String(length=255), nullable=True)
+    code_challenge: Optional[str] = Column(String(length=255), nullable=True)
+    code_challenge_method: Optional[str] = Column(String(length=255), nullable=True)
 
     client_id: UUID4 = Column(GUID, ForeignKey(Client.id, ondelete="CASCADE"), nullable=False)  # type: ignore
     client: Client = relationship("Client", lazy="joined")
+
+    def get_code_challenge_tuple(self) -> Optional[Tuple[str, str]]:
+        if self.code_challenge is not None:
+            return (self.code_challenge, cast(str, self.code_challenge_method))
+        return None
